/*
  COPYRIGHT NOTICE
  Copyright (c) 2011  Scott C. Neu and Arthur W. Toga

  See README.license for license notices.
*/

package edu.ucla.loni.debabel.processors.scott;

import edu.ucla.loni.debabel.processors.scott.dicom.*;
import edu.ucla.loni.debabel.processors.scott.identify.*;
import edu.ucla.loni.debabel.processors.scott.math.*;
import edu.ucla.loni.debabel.processors.scott.talairach.*;
import edu.ucla.loni.moduleio.spi.ProcessorSpi;
import java.util.Locale;
import java.util.Vector;

/**
 * Processor SPI (Service Provider Interface) for Scott's Processors.
 *
 * @version 1 September 2011
 */
public class ScottProcessorSpi extends ProcessorSpi
{
    /** Name of the vendor who supplied this plug-in. */
    private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

    /** Version of this plug-in. */
    private static String _version = "1.0";

    /** Name of the library of Processors. */
    private static String _libraryName = "Scott's Processor Library";

    /** Comment pertaining to the library. */
    private static String _libraryComment = "15 February 2011";

    /** Constructs a Scott Processor SPI. */
    public ScottProcessorSpi()
    {
	super(_vendorName, _version, _libraryName, _libraryComment);
    }

    /**
     * Returns a brief, human-readable description of this service provider and
     * its associated implementation.
     *
     * @param locale Locale for which the return value should be localized.
     *
     * @return Description of this service provider.
     */
    public String getDescription(Locale locale)
    {
	return _libraryName;
    }

    /**
     * Gets an array of fully-qualified class names of the Processors belonging
     * to the library.
     *
     * @return Fully-qualified class names of the Processors belonging to the
     *         library.
     */
    public String[] getProcessorClassNames()
    {
	Vector names = new Vector();

	// Add the class names
	names.add( AccessorInspector.class.getName() );
	names.add( AccessorToImage.class.getName() );
	names.add( AnalyzeFileNamer.class.getName() );
	names.add( ArrayConcatenator.class.getName() );
	names.add( ArrayIndexer.class.getName() );
	names.add( ArrayMaker.class.getName() );
	names.add( ArrayMaker2.class.getName() );
	names.add( ArraySearcher.class.getName() );
	names.add( ArraySizer.class.getName() );
	names.add( BufferedImageConverter.class.getName() );
	names.add( BufferedImageDivider.class.getName() );
	names.add( BufferedImageHistogram.class.getName() );
	names.add( BufferedImageMapper.class.getName() );
	names.add( BufferedImageMapper2.class.getName() );
	names.add( BufferedImageMapper3.class.getName() );
	names.add( BufferedImageInspector.class.getName() );
	names.add( BufferedImagePixelRange.class.getName() );
	names.add( BufferedImageRescaler.class.getName() );
	names.add( ByteSwapper.class.getName() );
	names.add( Constant.class.getName() );
	names.add( Defaulter.class.getName() );
	names.add( DicomDateParser.class.getName() );
	names.add( DicomDateTimeFormatter.class.getName() );
	names.add( DicomImageSorter.class.getName() );
	names.add( DicomImageSorter2.class.getName() );
	names.add( DicomImageSorter3.class.getName() );
	names.add( DicomTimeParser.class.getName() );
	names.add( DicomToMincSpace.class.getName() );
	names.add( DicomToNiftiSpace.class.getName() );
	names.add( DicomToTalairachSpace.class.getName() );
	names.add( DicomTreeCombiner.class.getName() );
	names.add( DicomTreeValueInsertor.class.getName() );
	names.add( DicomTreeValueExtractor.class.getName() );
	names.add( DicomTreeTagSplitter.class.getName() );
	names.add( DicomTreeVrSplitter.class.getName() );
	names.add( DicomUidFormatter.class.getName() );
	names.add( ExtremumFinder.class.getName() );
	names.add( FileNameParser.class.getName() );
	names.add( FileSizer.class.getName() );
	names.add( FixedArrayMaker.class.getName() );
	names.add( GeToDicomSpace.class.getName() );
	names.add( Identity.class.getName() );
	names.add( ImageAndContourCombiner.class.getName() );
	names.add( ImageToAccessor.class.getName() );
	names.add( MincToDicomSpace.class.getName() );
	names.add( MincToTalairachSpace.class.getName() );
	names.add( MultiStringConcatenator.class.getName() );
	names.add( NiftiToDicomSpace.class.getName() );
	names.add( NrrdToDicomSpace.class.getName() );
	names.add( NumberAccumulator.class.getName() );
	names.add( PrimitiveTypeConverter.class.getName() );
	names.add( Round.class.getName() );
	names.add( Siemens00291010Decoder.class.getName() );
	names.add( SiemensMosaicFieldDecoder.class.getName() );
	names.add( Sorter.class.getName() );
	names.add( StringArray.class.getName() );
	names.add( StringChecker.class.getName() );
	names.add( StringHasher.class.getName() );
	names.add( StringTrimmer.class.getName() );
	names.add( StringTruncator.class.getName() );
	names.add( TalairachCrossProduct.class.getName() );
	names.add( TalairachImageReformatter.class.getName() );
	names.add( TalairachPointTransformer.class.getName() );
	names.add( TreeFinder.class.getName() );
	names.add( ValueHolder.class.getName() );
	names.add( ValueMapper.class.getName() );

	// Return the String array
	return (String[])names.toArray(new String[0]);
    }
}
