/*
COPYRIGHT NOTICE
Copyright (c) 2003  Scott C. Neu, Daniel J. Valentino, and Arthur W. Toga

See README.license for license notices.
 */

package edu.ucla.loni.debabel.processors.vann;

import edu.ucla.loni.moduleio.spi.ProcessorSpi;
import java.util.Locale;
import java.util.Vector;

/**
 * Processor SPI (Service Provider Interface) for Debabeler Standard Library.
 *
 * @version 5 June 2003
 */
public class VannProcessorSpi extends ProcessorSpi
{
  /** Name of the vendor who supplied this plug-in. */
  private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

  /** Version of this plug-in. */
  private static String _version = "1.0";

  /** Name of the library of Processors. */
  private static String _libraryName 
                          = "LONI Debabeler Vann's Processor Library";

  /** Comment pertaining to the library. */
  private static String _libraryComment 
                          = "Authors: Vann, Created: 5 June 2003";

  /** Constructs a Standard Library Processor SPI. */
  public VannProcessorSpi()
    {
      super(_vendorName, _version, _libraryName, _libraryComment);
    }

  /**
   * Returns a brief, human-readable description of this service provider and
   * its associated implementation.
   *
   * @param locale Locale for which the return value should be localized.
   *
   * @return Description of this service provider.
   */
  public String getDescription(Locale locale)
    {
      return _libraryName;
    }

  /**
   * Gets an array of fully-qualified class names of the Processors belonging
   * to the library.
   *
   * @return Fully-qualified class names of the Processors belonging to the
   *         library.
   */
  public String[] getProcessorClassNames()
    {
      Vector names = new Vector();

      // Add the class names
      names.add( NullArray.class.getName() );
      names.add( BufferedImageSorter.class.getName() );
      names.add( Cryptor.class.getName() );
      names.add( CurrentDateTime.class.getName() );
      names.add( DateConverter.class.getName() );
      names.add( StringPadder.class.getName() );
      names.add( DicomDateFormatter.class.getName() );
      names.add( DicomTimeFormatter.class.getName() );
      names.add( RawImageConverter.class.getName() );
      names.add( TalairachToDicomSpace.class.getName() );
      names.add( FileNameReplacer.class.getName() );
      names.add( BufferedImageProperties.class.getName() );
      
      // Convert the Vector to a String array
      String[] array = new String[ names.size() ];
      for (int i = 0; i < array.length; i++) {
	array[i] = (String)names.elementAt(i);
      }

      // Return the String array
      return array;
    }
}
